opynfield

A Python package to analyze open field exploration data

[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.15794680.svg)](https://doi.org/10.5281/zenodo.15794680)

See the documentation at: https://ellenmcmullen.github.io/opynfield/index.html
